summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteawayaction.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopeteawayaction.h')
-rw-r--r--kopete/libkopete/kopeteawayaction.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kopete/libkopete/kopeteawayaction.h b/kopete/libkopete/kopeteawayaction.h
index f8ab9d64..c787e7e7 100644
--- a/kopete/libkopete/kopeteawayaction.h
+++ b/kopete/libkopete/kopeteawayaction.h
@@ -46,20 +46,20 @@ class KOPETE_EXPORT AwayAction : public KSelectAction
* @p text, @p pix, @p cut, @p receiver, @p slot, @p parent and
* @p name are all handled by KSelectAction.
**/
- AwayAction(const QString &text, const QIconSet &pix,
- const KShortcut &cut, const QObject *receiver, const char *slot,
- QObject *parent, const char *name = 0);
+ AwayAction(const TQString &text, const TQIconSet &pix,
+ const KShortcut &cut, const TQObject *receiver, const char *slot,
+ TQObject *parent, const char *name = 0);
/**
* Constructor
* @param status the OnlineStatus that appears in the signal
* @param slot must have the following signature: ( const OnlineStatus &, const QString & )
* @p text, @p pix, @p cut, @p receiver, @p slot, @p parent and
* @p name are all handled by KSelectAction.
**/
- AwayAction(const OnlineStatus &status, const QString &text, const QIconSet &pix,
- const KShortcut &cut, const QObject *receiver, const char *slot,
- QObject *parent, const char *name = 0);
+ AwayAction(const OnlineStatus &status, const TQString &text, const TQIconSet &pix,
+ const KShortcut &cut, const TQObject *receiver, const char *slot,
+ TQObject *parent, const char *name = 0);
/**
* Destructor.
@@ -70,12 +70,12 @@ class KOPETE_EXPORT AwayAction : public KSelectAction
/**
* @brief Emits when the user selects an away message
*/
- void awayMessageSelected( const QString & );
+ void awayMessageSelected( const TQString & );
/**
* same as above, but with the saved status
*/
- void awayMessageSelected( const Kopete::OnlineStatus& , const QString & );
+ void awayMessageSelected( const Kopete::OnlineStatus& , const TQString & );
private slots:
void slotAwayChanged();
@@ -46,20 +46,20 @@ class KOPETE_EXPORT AwayAction : public KSelectAction
* Constructor
* @param status the OnlineStatus that appears in the signal
- * @param slot must have the following signature: ( const OnlineStatus &, const QString & )
+ * @param slot must have the following signature: ( const OnlineStatus &, const TQString & )
* @p text, @p pix, @p cut, @p receiver, @p slot, @p parent and
* @p name are all handled by KSelectAction.